﻿/*#############################################################
Developed by: Fatih Sever | www.fatihsever.com

Don't hesitate to use and modify but please provide credits.
#############################################################*/

using System;
using System.Collections;
using System.Collections.Generic;
using System.Web;
using System.Xml;
using System.IO;
using BlogEngine.Core;
using System.Data;
using System.Globalization;
using BlogEngine.Core.Providers;
using System.Configuration;
using System.Data.Common;
using System.Configuration.Provider;

namespace Controls
{
    #region Answer Object
    public class Answer
    {
        #region Constructor

        public Answer()
        {
            id = Guid.NewGuid();
        }

        #endregion

        #region Fields & Properties

        private Guid id;
        public Guid Id
        {
            get { return id; }
            set { id = value; }
        }

        private string text;
        public string Text
        {
            get { return text; }
            set { text = value; }
        }

        private int vote;
        public int Vote
        {
            get { return vote; }
            set { vote = value; }
        }

        #endregion

    }
    #endregion

    #region Poll Object
    public class Poll
    {
        #region Constructor

        public Poll()
        {
            id = Guid.NewGuid();
            answers = new List<Answer>();
        }

        #endregion

        #region Fields & Properties

        private Guid id;
        public Guid Id
        {
            get { return id; }
            set { id = value; }
        }

        private string question;
        public string Question
        {
            get { return question; }
            set { question = value; }
        }

        private List<Answer> answers;
        public List<Answer> Answers
        {
            get { return answers; }
            set { answers = value; }
        }

        private bool activated;
        public bool Activated
        {
            get { return activated; }
            set { activated = value; }
        }

        private DateTime expirationDate;
        public DateTime ExpirationDate
        {
            get { return expirationDate; }
            set { expirationDate = value; }
        }

        private DateTime dateCreated;
        public DateTime DateCreated
        {
            get { return dateCreated; }
            set { dateCreated = value; }
        }

        private int totalVote;
        public int TotalVote
        {
            get { return totalVote; }
            set { totalVote = value; }
        }

        #endregion
    }

    #endregion

    #region Polls Control

    public static class Polls
    {
        #region Fields

        private static string folder = HttpContext.Current.Server.MapPath(BlogSettings.Instance.StorageLocation);
        private static BlogProviderSection section = (BlogProviderSection)ConfigurationManager.GetSection("BlogEngine/blogProvider");
        private static string connString = ConfigurationManager.ConnectionStrings["BlogEngine"].ConnectionString;
        private static DbProviderFactory provider = DbProviderFactories.GetFactory(ConfigurationManager.ConnectionStrings["BlogEngine"].ProviderName);
        private static string parmPrefix = section.Providers["DbBlogProvider"].Parameters["parmPrefix"] != null ? section.Providers["DbBlogProvider"].Parameters["parmPrefix"].ToString() : "@";
        private static string tablePrefix = section.Providers["DbBlogProvider"].Parameters["tablePrefix"] != null ? section.Providers["DbBlogProvider"].Parameters["tablePrefix"].ToString() : "be_";

        #endregion

        #region Methods

        private static void CreateXml(Poll poll, List<Poll> polls, bool IsDelete)
        {
            using (XmlTextWriter pollWriter = new XmlTextWriter(folder + "polls.xml", System.Text.Encoding.UTF8))
            {
                pollWriter.Formatting = Formatting.Indented;
                pollWriter.Indentation = 4;
                pollWriter.WriteStartDocument(true);
                pollWriter.WriteStartElement("polls");

                foreach (Poll pol in polls)
                {
                    pollWriter.WriteStartElement("poll");
                    pollWriter.WriteAttributeString("id", pol.Id.ToString());
                    if (!IsDelete)
                    {
                        if (!poll.Activated)
                        {
                            pollWriter.WriteAttributeString("activated", pol.Activated.ToString());
                        }
                        else
                        {
                            if (pol.Id != poll.Id)
                            {
                                pollWriter.WriteAttributeString("activated", "False");
                            }
                            else
                            {
                                pollWriter.WriteAttributeString("activated", "True");
                            }
                        }
                    }
                    else
                    {
                        pollWriter.WriteAttributeString("activated", pol.Activated.ToString());
                    }
                    pollWriter.WriteAttributeString("expirationdate", pol.ExpirationDate.AddHours(-BlogSettings.Instance.Timezone).ToString("yyyy-MM-dd HH:mm:ss", CultureInfo.InvariantCulture));
                    pollWriter.WriteAttributeString("datecreated", pol.DateCreated.AddHours(-BlogSettings.Instance.Timezone).ToString("yyyy-MM-dd HH:mm:ss", CultureInfo.InvariantCulture));

                    pollWriter.WriteStartElement("question");
                    pollWriter.WriteValue(pol.Question);
                    pollWriter.WriteEndElement();

                    pollWriter.WriteStartElement("answers");

                    foreach (Answer ans in pol.Answers)
                    {
                        pollWriter.WriteStartElement("answer");
                        pollWriter.WriteAttributeString("id", ans.Id.ToString());
                        pollWriter.WriteAttributeString("vote", ans.Vote.ToString());
                        pollWriter.WriteValue(ans.Text);
                        pollWriter.WriteEndElement();
                    }

                    pollWriter.WriteEndElement();
                    pollWriter.WriteEndElement();
                }

                pollWriter.WriteEndElement();
            }
        }

        public static bool InsertPoll(Poll poll)
        {
            if (section.DefaultProvider == "XmlBlogProvider")
            {
                List<Poll> polls = new List<Poll>();

                if (File.Exists(folder + "polls.xml"))
                {
                    polls = FillPolls();
                }
                polls.Add(poll);

                CreateXml(poll, polls, false);

                return true;
            }
            else if (section.DefaultProvider == "DbBlogProvider")
            {
                try
                {
                    using (DbConnection conn = provider.CreateConnection())
                    {
                        conn.ConnectionString = connString;
                        conn.Open();

                        using (DbCommand cmd = conn.CreateCommand())
                        {
                            string sqlQuery;

                            if (poll.Activated)
                            {
                                sqlQuery = "UPDATE " + tablePrefix + "Polls SET Activated=@false;" +
                                    "INSERT INTO " + tablePrefix + "Polls" +
                                      "(PollID,Question,Activated,ExpirationDate,DateCreated) " +
                                      "VALUES(@pollId,@question,@activated,@expirationDate,@dateCreated)";
                            }
                            else
                            {
                                sqlQuery = "INSERT INTO " + tablePrefix + "Polls" +
                                           "(PollID,Question,Activated,ExpirationDate,DateCreated) " +
                                           "VALUES(@pollId,@question,@activated,@expirationDate,@dateCreated)";
                            }

                            if (parmPrefix != "@")
                            {
                                sqlQuery = sqlQuery.Replace("@", parmPrefix);
                            }
                            cmd.CommandText = sqlQuery;
                            cmd.CommandType = CommandType.Text;

                            DbParameter pID = provider.CreateParameter();
                            pID.ParameterName = parmPrefix + "pollId";
                            pID.Value = poll.Id;
                            cmd.Parameters.Add(pID);

                            DbParameter pQuestion = provider.CreateParameter();
                            pQuestion.ParameterName = parmPrefix + "question";
                            pQuestion.Value = poll.Question;
                            cmd.Parameters.Add(pQuestion);

                            DbParameter pActivated = provider.CreateParameter();
                            pActivated.ParameterName = parmPrefix + "activated";
                            pActivated.Value = poll.Activated;
                            cmd.Parameters.Add(pActivated);

                            DbParameter pExpire = provider.CreateParameter();
                            pExpire.ParameterName = parmPrefix + "expirationDate";
                            pExpire.Value = poll.ExpirationDate;
                            cmd.Parameters.Add(pExpire);

                            DbParameter pDate = provider.CreateParameter();
                            pDate.ParameterName = parmPrefix + "dateCreated";
                            pDate.Value = poll.DateCreated;
                            cmd.Parameters.Add(pDate);

                            DbParameter pFalse = provider.CreateParameter();
                            pFalse.ParameterName = parmPrefix + "false";
                            pFalse.Value = false;
                            cmd.Parameters.Add(pFalse);

                            cmd.ExecuteNonQuery();


                            // Answers    

                            foreach (Answer answer in poll.Answers)
                            {
                                sqlQuery = "INSERT INTO " + tablePrefix + "PollAnswers" +
                                       "(AnswerID,PollID,Answer,Vote) " +
                                       "VALUES(@answerId,@aPollId,@answer,@vote)";

                                if (parmPrefix != "@")
                                {
                                    sqlQuery = sqlQuery.Replace("@", parmPrefix);
                                }
                                cmd.CommandText = sqlQuery;
                                cmd.CommandType = CommandType.Text;

                                DbParameter aID = provider.CreateParameter();
                                aID.ParameterName = parmPrefix + "answerId";
                                aID.Value = answer.Id;
                                cmd.Parameters.Add(aID);

                                DbParameter aPID = provider.CreateParameter();
                                aPID.ParameterName = parmPrefix + "aPollId";
                                aPID.Value = poll.Id;
                                cmd.Parameters.Add(aPID);

                                DbParameter aAnswer = provider.CreateParameter();
                                aAnswer.ParameterName = parmPrefix + "answer";
                                aAnswer.Value = answer.Text;
                                cmd.Parameters.Add(aAnswer);

                                DbParameter aVote = provider.CreateParameter();
                                aVote.ParameterName = parmPrefix + "vote";
                                aVote.Value = answer.Vote;
                                cmd.Parameters.Add(aVote);

                                cmd.ExecuteNonQuery();

                                cmd.Parameters.Clear();
                            }
                        }
                        conn.Close();
                    }

                    return true;
                }
                catch
                {
                    return false;
                }
            }
            else
            {
                throw new System.Configuration.Provider.ProviderException("Unable to load default BlogProvider");
            }
        }

        public static bool UpdatePoll(Poll poll, string pollId)
        {
            try
            {
                if (section.DefaultProvider == "XmlBlogProvider")
                {

                    List<Poll> polls = FillPolls();

                    foreach (Poll pol in polls.ToArray())
                    {
                        if (pol.Id == new Guid(pollId))
                        {
                            polls.Remove(pol);
                        }
                    }

                    polls.Add(poll);

                    CreateXml(poll, polls, false);

                    return true;

                }
                else if (section.DefaultProvider == "DbBlogProvider")
                {
                    if (DeletePoll(pollId))
                    {
                        InsertPoll(poll);
                    }

                    return true;
                }
                else
                {
                    throw new System.Configuration.Provider.ProviderException("Unable to load default BlogProvider");
                }
            }
            catch
            {
                return false;
            }
        }

        public static bool DeletePoll(string pollId)
        {
            if (section.DefaultProvider == "XmlBlogProvider")
            {
                List<Poll> polls = FillPolls();

                foreach (Poll pol in polls.ToArray())
                {
                    if (pol.Id == new Guid(pollId))
                    {
                        polls.Remove(pol);
                    }
                }

                CreateXml(null, polls, true);
            }
            else if (section.DefaultProvider == "DbBlogProvider")
            {
                using (DbConnection conn = provider.CreateConnection())
                {
                    conn.ConnectionString = connString;
                    conn.Open();

                    using (DbCommand cmd = conn.CreateCommand())
                    {
                        string sqlQuery = "DELETE FROM " + tablePrefix + "PollAnswers WHERE PollID = @pollId;" +
                                     "DELETE FROM " + tablePrefix + "Polls WHERE PollID = @pollId;";

                        if (parmPrefix != "@")
                        {
                            sqlQuery = sqlQuery.Replace("@", parmPrefix);
                        }
                        cmd.CommandText = sqlQuery;
                        cmd.CommandType = CommandType.Text;

                        DbParameter pID = provider.CreateParameter();
                        pID.ParameterName = parmPrefix + "pollId";
                        pID.Value = new Guid(pollId);
                        cmd.Parameters.Add(pID);

                        cmd.ExecuteNonQuery();
                    }

                    conn.Close();
                }
            }
            else
            {
                throw new System.Configuration.Provider.ProviderException("Unable to load default BlogProvider");
            }

            return true;
        }

        public static Poll SelectPoll()
        {
            Poll poll = new Poll(); ;

            if (section.DefaultProvider == "XmlBlogProvider")
            {
                if (!File.Exists(folder + "polls.xml"))
                {
                    return null;
                }

                XmlDocument doc = new XmlDocument();
                try
                {
                    doc.Load(folder + "polls.xml");
                }
                catch
                {
                    return null;
                }

                foreach (XmlNode node in doc.SelectNodes("polls/poll"))
                {
                    if (node == null)
                    {
                        return null;
                    }

                    bool IsActivated = Convert.ToBoolean(node.Attributes["activated"].InnerText);

                    if (IsActivated)
                    {
                        poll.Id = new Guid(node.Attributes["id"].InnerText);
                        poll.Activated = IsActivated;
                        poll.ExpirationDate = DateTime.Parse(node.Attributes["expirationdate"].InnerText, System.Globalization.CultureInfo.InvariantCulture);
                        poll.DateCreated = DateTime.Parse(node.Attributes["datecreated"].InnerText, System.Globalization.CultureInfo.InvariantCulture);
                        poll.Question = node.ChildNodes[0].InnerText;

                        Answer answer = null;

                        foreach (XmlNode node2 in node.SelectNodes("answers/answer"))
                        {
                            answer = new Answer();

                            answer.Id = new Guid(node2.Attributes["id"].InnerText);
                            answer.Vote = Convert.ToInt32(node2.Attributes["vote"].InnerText);
                            answer.Text = node2.ChildNodes[0].InnerText;

                            poll.TotalVote += Convert.ToInt32(node2.Attributes["vote"].InnerText);

                            poll.Answers.Add(answer);
                        }

                        return poll;
                    }
                }

                return null;
            }
            else if (section.DefaultProvider == "DbBlogProvider")
            {
                try
                {
                    using (DbConnection conn = provider.CreateConnection())
                    {
                        conn.ConnectionString = connString;

                        using (DbCommand cmd = conn.CreateCommand())
                        {
                            string sqlQuery = "SELECT * FROM " + tablePrefix + "Polls " +
                                        "WHERE Activated = @activated";

                            if (parmPrefix != "@")
                            {
                                sqlQuery = sqlQuery.Replace("@", parmPrefix);
                            }
                            cmd.CommandText = sqlQuery;
                            cmd.CommandType = CommandType.Text;

                            DbParameter dpActivated = provider.CreateParameter();
                            dpActivated.ParameterName = parmPrefix + "activated";
                            dpActivated.Value = true;
                            cmd.Parameters.Add(dpActivated);

                            conn.Open();

                            using (DbDataReader rdr = cmd.ExecuteReader())
                            {
                                if (rdr.HasRows)
                                {
                                    rdr.Read();

                                    poll.Id = rdr.GetGuid(0);
                                    if (!rdr.IsDBNull(1))
                                    {
                                        poll.Question = rdr.GetString(1);
                                    }
                                    if (!rdr.IsDBNull(2))
                                    {
                                        poll.Activated = rdr.GetBoolean(2);
                                    }
                                    if (!rdr.IsDBNull(3))
                                    {
                                        poll.ExpirationDate = rdr.GetDateTime(3);
                                    }
                                    if (!rdr.IsDBNull(4))
                                    {
                                        poll.DateCreated = rdr.GetDateTime(4);
                                    }
                                }
                                else
                                {
                                    return null;
                                }
                            }


                            // Answers    

                            sqlQuery = "SELECT * FROM " + tablePrefix + "PollAnswers " +
                                        "WHERE PollID = @pollId";

                            if (parmPrefix != "@")
                            {
                                sqlQuery = sqlQuery.Replace("@", parmPrefix);
                            }
                            cmd.CommandText = sqlQuery;
                            cmd.CommandType = CommandType.Text;

                            DbParameter dpID = provider.CreateParameter();
                            dpID.ParameterName = parmPrefix + "pollId";
                            dpID.Value = poll.Id;
                            cmd.Parameters.Add(dpID);

                            using (DbDataReader rdr = cmd.ExecuteReader())
                            {
                                Answer answer = null;

                                while (rdr.Read())
                                {
                                    answer = new Answer();

                                    answer.Id = rdr.GetGuid(0);
                                    if (!rdr.IsDBNull(2))
                                    {
                                        answer.Text = rdr.GetString(2);
                                    }
                                    if (!rdr.IsDBNull(3))
                                    {
                                        answer.Vote = rdr.GetInt32(3);
                                        poll.TotalVote += rdr.GetInt32(3);
                                    }

                                    poll.Answers.Add(answer);
                                }
                            }
                        }
                        conn.Close();
                    }
                }
                catch
                {
                    return null;
                }
            }
            else
            {
                throw new System.Configuration.Provider.ProviderException("Unable to load default BlogProvider");
            }

            return poll;
        }

        public static Poll SelectPoll(string pollId)
        {
            Poll poll = new Poll();

            if (section.DefaultProvider == "XmlBlogProvider")
            {
                if (!File.Exists(folder + "polls.xml"))
                {
                    return null;
                }

                XmlDocument doc = new XmlDocument();
                try
                {
                    doc.Load(folder + "polls.xml");
                }
                catch
                {
                    return null;
                }

                foreach (XmlNode node in doc.SelectNodes("polls/poll"))
                {
                    if (node == null)
                    {
                        return null;
                    }

                    if (node.Attributes["id"].InnerText.Trim() == pollId)
                    {
                        poll.Id = new Guid(node.Attributes["id"].InnerText);
                        poll.Activated = Convert.ToBoolean(node.Attributes["activated"].InnerText);
                        poll.ExpirationDate = DateTime.Parse(node.Attributes["expirationdate"].InnerText, System.Globalization.CultureInfo.InvariantCulture);
                        poll.DateCreated = DateTime.Parse(node.Attributes["datecreated"].InnerText, System.Globalization.CultureInfo.InvariantCulture);
                        poll.Question = node.ChildNodes[0].InnerText;

                        Answer answer = null;

                        foreach (XmlNode node2 in node.SelectNodes("answers/answer"))
                        {
                            answer = new Answer();

                            answer.Id = new Guid(node2.Attributes["id"].InnerText);
                            answer.Vote = Convert.ToInt32(node2.Attributes["vote"].InnerText);
                            answer.Text = node2.ChildNodes[0].InnerText;

                            Convert.ToInt32(node2.Attributes["vote"].InnerText);

                            poll.TotalVote += Convert.ToInt32(node2.Attributes["vote"].InnerText);

                            poll.Answers.Add(answer);
                        }
                    }
                }
            }
            else if (section.DefaultProvider == "DbBlogProvider")
            {
                using (DbConnection conn = provider.CreateConnection())
                {
                    conn.ConnectionString = connString;

                    using (DbCommand cmd = conn.CreateCommand())
                    {

                        string sqlQuery = "SELECT * FROM " + tablePrefix + "Polls " +
                                   "WHERE PollID = @pollId";

                        if (parmPrefix != "@")
                        {
                            sqlQuery = sqlQuery.Replace("@", parmPrefix);
                        }
                        cmd.CommandText = sqlQuery;
                        cmd.CommandType = CommandType.Text;

                        DbParameter dpID = provider.CreateParameter();
                        dpID.ParameterName = parmPrefix + "pollId";
                        dpID.Value = new Guid(pollId);
                        cmd.Parameters.Add(dpID);

                        conn.Open();

                        using (DbDataReader rdr = cmd.ExecuteReader())
                        {
                            if (rdr.HasRows)
                            {
                                rdr.Read();

                                poll.Id = rdr.GetGuid(0);
                                if (!rdr.IsDBNull(1))
                                {
                                    poll.Question = rdr.GetString(1);
                                }
                                if (!rdr.IsDBNull(2))
                                {
                                    poll.Activated = rdr.GetBoolean(2);
                                }
                                if (!rdr.IsDBNull(3))
                                {
                                    poll.ExpirationDate = rdr.GetDateTime(3);
                                }
                                if (!rdr.IsDBNull(4))
                                {
                                    poll.DateCreated = rdr.GetDateTime(4);
                                }
                            }
                            else
                            {
                                return null;
                            }
                        }


                        // Answers    

                        sqlQuery = "SELECT * FROM " + tablePrefix + "PollAnswers " +
                                    "WHERE PollID = @aPollId";

                        if (parmPrefix != "@")
                        {
                            sqlQuery = sqlQuery.Replace("@", parmPrefix);
                        }
                        cmd.CommandText = sqlQuery;
                        cmd.CommandType = CommandType.Text;

                        DbParameter dpAID = provider.CreateParameter();
                        dpAID.ParameterName = parmPrefix + "aPollId";
                        dpAID.Value = poll.Id;
                        cmd.Parameters.Add(dpAID);

                        using (DbDataReader rdr = cmd.ExecuteReader())
                        {
                            Answer answer = null;

                            while (rdr.Read())
                            {
                                answer = new Answer();

                                answer.Id = rdr.GetGuid(0);
                                if (!rdr.IsDBNull(2))
                                {
                                    answer.Text = rdr.GetString(2);
                                }
                                if (!rdr.IsDBNull(3))
                                {
                                    answer.Vote = rdr.GetInt32(3);
                                    poll.TotalVote += rdr.GetInt32(3);
                                }

                                poll.Answers.Add(answer);
                            }
                        }
                    }
                    conn.Close();
                }
            }
            else
            {
                throw new System.Configuration.Provider.ProviderException("Unable to load default BlogProvider");
            }

            return poll;
        }

        public static List<Poll> FillPolls()
        {
            List<Poll> polls = new List<Poll>();

            if (section.DefaultProvider == "XmlBlogProvider")
            {
                if (!File.Exists(folder + "polls.xml"))
                {
                    return null;
                }

                XmlDocument doc = new XmlDocument();
                try
                {
                    doc.Load(folder + "polls.xml");
                }
                catch
                {
                    return null;
                }

                Poll poll = null;

                foreach (XmlNode node in doc.SelectNodes("polls/poll"))
                {
                    if (node == null)
                    {
                        return null;
                    }

                    poll = new Poll();

                    poll.Id = new Guid(node.Attributes["id"].InnerText);
                    poll.Activated = Convert.ToBoolean(node.Attributes["activated"].InnerText);
                    poll.ExpirationDate = DateTime.Parse(node.Attributes["expirationdate"].InnerText, System.Globalization.CultureInfo.InvariantCulture);
                    poll.DateCreated = DateTime.Parse(node.Attributes["datecreated"].InnerText, System.Globalization.CultureInfo.InvariantCulture);
                    poll.Question = node.ChildNodes[0].InnerText;

                    Answer answer = null;

                    foreach (XmlNode node2 in node.SelectNodes("answers/answer"))
                    {
                        answer = new Answer();

                        answer.Id = new Guid(node2.Attributes["id"].InnerText);
                        answer.Vote = Convert.ToInt32(node2.Attributes["vote"].InnerText);
                        answer.Text = node2.ChildNodes[0].InnerText;

                        poll.TotalVote += Convert.ToInt32(node2.Attributes["vote"].InnerText);

                        poll.Answers.Add(answer);
                    }

                    polls.Add(poll);
                }
            }
            else if (section.DefaultProvider == "DbBlogProvider")
            {
                try
                {
                    using (DbConnection conn = provider.CreateConnection())
                    {
                        conn.ConnectionString = connString;

                        using (DbCommand cmd = conn.CreateCommand())
                        {

                            string sqlQuery = "SELECT * FROM " + tablePrefix + "Polls";
                            cmd.CommandText = sqlQuery;
                            cmd.CommandType = CommandType.Text;

                            conn.Open();

                            using (DbDataReader rdr = cmd.ExecuteReader())
                            {
                                Poll poll = null;

                                while (rdr.Read())
                                {
                                    if (rdr.HasRows)
                                    {
                                        poll = new Poll();

                                        poll.Id = rdr.GetGuid(0);
                                        if (!rdr.IsDBNull(1))
                                        {
                                            poll.Question = rdr.GetString(1);
                                        }
                                        if (!rdr.IsDBNull(2))
                                        {
                                            poll.Activated = rdr.GetBoolean(2);
                                        }
                                        if (!rdr.IsDBNull(3))
                                        {
                                            poll.ExpirationDate = rdr.GetDateTime(3);
                                        }
                                        if (!rdr.IsDBNull(4))
                                        {
                                            poll.DateCreated = rdr.GetDateTime(4);
                                        }

                                        // Answers    
                                        using (DbConnection conn2 = provider.CreateConnection())
                                        {
                                            conn2.ConnectionString = connString;

                                            using (DbCommand cmd2 = conn2.CreateCommand())
                                            {
                                                string sqlQuery2 = "SELECT * FROM " + tablePrefix + "PollAnswers " +
                                                            "WHERE PollID = @pollId";

                                                if (parmPrefix != "@")
                                                {
                                                    sqlQuery2 = sqlQuery2.Replace("@", parmPrefix);
                                                }
                                                cmd2.CommandText = sqlQuery2;
                                                cmd2.CommandType = CommandType.Text;

                                                DbParameter dpID = provider.CreateParameter();
                                                dpID.ParameterName = parmPrefix + "pollId";
                                                dpID.Value = poll.Id;
                                                cmd2.Parameters.Add(dpID);

                                                conn2.Open();

                                                using (DbDataReader rdr2 = cmd2.ExecuteReader())
                                                {
                                                    Answer answer = null;

                                                    while (rdr2.Read())
                                                    {
                                                        answer = new Answer();

                                                        answer.Id = rdr2.GetGuid(0);
                                                        if (!rdr2.IsDBNull(2))
                                                        {
                                                            answer.Text = rdr2.GetString(2);
                                                        }
                                                        if (!rdr2.IsDBNull(3))
                                                        {
                                                            answer.Vote = rdr2.GetInt32(3);
                                                            poll.TotalVote += rdr2.GetInt32(3);
                                                        }

                                                        poll.Answers.Add(answer);
                                                    }
                                                }

                                                conn2.Close();
                                            }

                                            polls.Add(poll);
                                        }
                                    }
                                    else
                                    {
                                        return null;
                                    }
                                }
                            }

                            conn.Close();
                        }
                    }
                }
                catch
                {
                    return null;
                }
            }
            else
            {
                throw new System.Configuration.Provider.ProviderException("Unable to load default BlogProvider");
            }

            return polls;
        }

        #endregion
    }
    #endregion
}