﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Controls;
using BlogEngine.Core.Providers;
using System.Configuration;
using System.IO;
using BlogEngine.Core;
using System.Collections.Specialized;

public partial class widgets_Poll_edit : WidgetEditBase
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            GetAllPolls();

            if (Session["Answers"] != null)
            {
                Session["Answers"] = null;
            }

            StringDictionary settings = GetSettings();
            ShowResults_rbl.SelectedValue = settings["ShowResultButtonVisible"];
            PollsArchive_rbl.SelectedValue = settings["PollsArchiveButtonVisible"];
        }
    }

    public override void Save()
    {
        StringDictionary settings = GetSettings();
        settings["ShowResultButtonVisible"] = ShowResults_rbl.SelectedValue;
        settings["PollsArchiveButtonVisible"] = PollsArchive_rbl.SelectedValue;

        SaveSettings(settings);
    }

    private void GetAllPolls()
    {
        Polls_ddl.Items.Clear();

        Polls_ddl.Items.Add("Selecciona votación para editar o borrar");

        Polls_ddl.DataTextField = "Question";
        Polls_ddl.DataValueField = "Id";
        Polls_ddl.DataSource = Polls.FillPolls();
        Polls_ddl.DataBind();
    }

    private void GetPoll(string pollId)
    {
        Poll poll = Polls.SelectPoll(pollId);

        Question_tb.Text = poll.Question;
        Activated_cbx.Checked = Convert.ToBoolean(poll.Activated);

        if (poll.ExpirationDate > DateTime.Parse("01/01/2008 00:00:00"))
        {
            Day_ddl.SelectedValue = poll.ExpirationDate.Day.ToString();
            Month_ddl.SelectedValue = poll.ExpirationDate.Month.ToString();
            Year_ddl.SelectedValue = poll.ExpirationDate.Year.ToString();
        }
        else
        {
            Day_ddl.SelectedIndex = 0;
            Month_ddl.SelectedIndex = 0;
            Year_ddl.SelectedIndex = 0;
        }

        Session["Answers"] = poll.Answers;

        Answers_gv.DataSource = (List<Answer>)Session["Answers"];
        Answers_gv.DataBind();
    }

    private Poll SetPoll()
    {
        Poll poll = new Poll();
        poll.Id = Guid.NewGuid();
        poll.Question = Question_tb.Text;

        string expirationDate = "";
        if (Day_ddl.SelectedIndex > 0 && Month_ddl.SelectedIndex > 0 && Year_ddl.SelectedIndex > 0)
        {
            expirationDate = Day_ddl.SelectedValue + "/" + Month_ddl.SelectedValue + "/" + Year_ddl.SelectedValue;
        }

        poll.ExpirationDate = !String.IsNullOrEmpty(expirationDate) ? DateTime.Parse(expirationDate) : DateTime.Parse("01/01/2000 00:00:00");
        
        poll.DateCreated = DateTime.Now;
        poll.Activated = Activated_cbx.Checked;
        poll.Answers = (List<Answer>)Session["Answers"];

        return poll;
    }

    private Poll SetPoll(string pollId)
    {
        Poll poll = new Poll();
        poll.Id = new Guid(pollId);
        poll.Question = Question_tb.Text;

        string expirationDate = "";
        if (Day_ddl.SelectedIndex > 0 && Month_ddl.SelectedIndex > 0 && Year_ddl.SelectedIndex > 0)
        {
            expirationDate = Day_ddl.SelectedValue + "/" + Month_ddl.SelectedValue + "/" + Year_ddl.SelectedValue;
        }

        poll.ExpirationDate = !String.IsNullOrEmpty(expirationDate) ? DateTime.Parse(expirationDate) : DateTime.Parse("01/01/2000 00:00:00");
       
        poll.DateCreated = DateTime.Now;
        poll.Activated = Activated_cbx.Checked;
        poll.Answers = (List<Answer>)Session["Answers"];

        return poll;
    }

    protected void Polls_ddl_SelectedIndexChanged(object sender, EventArgs e)
    {
        if (Polls_ddl.SelectedIndex != 0)
        {
            GetPoll(Polls_ddl.SelectedValue.ToString());
            Polls_ddl.Items[0].Text = "Add New Poll";
            Add_bt.Visible = false;
            Update_bt.Visible = true;
            Delete_bt.Visible = true;
        }
        else
        {
            ResetPollForm();
        }

        Messages_lb.Text = "";
    }

    protected void ResetPollForm()
    {
        Question_tb.Text = "";
        Activated_cbx.Checked = true;
        Day_ddl.SelectedIndex = 0;
        Month_ddl.SelectedIndex = 0;
        Year_ddl.SelectedIndex = 0;

        Session["Answers"] = null;
        Answers_gv.Dispose();
        Answers_gv.DataBind();

        Polls_ddl.Items[0].Text = "Selecciona votación para editar o borrar";
        Add_bt.Visible = true;
        Update_bt.Visible = false;
        Delete_bt.Visible = false;
        Answer_bt.Text = "Añadir respuesta";
        Answer_tb.Text = "";
    }

    protected void Add_bt_Click(object sender, EventArgs e)
    {
        if (!String.IsNullOrEmpty(Question_tb.Text))
        {
            if (Polls.InsertPoll(SetPoll()))
            {
                Messages_lb.Text = "Añadido con éxito";
                ResetPollForm();
                GetAllPolls();
            }
            else
            {
                Messages_lb.Text = "There is a database problem!<br/>Please check your database.";
                Messages_lb.ForeColor = System.Drawing.Color.Red;
            }
        }
    }

    protected void Update_bt_Click(object sender, EventArgs e)
    {
        if (Polls_ddl.SelectedIndex != 0)
        {
            Polls.UpdatePoll(SetPoll(Polls_ddl.SelectedValue.ToString()), Polls_ddl.SelectedValue.ToString());

            Messages_lb.Text = "Actualizado con éxito";
            ResetPollForm();
            GetAllPolls();
        }
    }
    protected void Delete_bt_Click(object sender, EventArgs e)
    {
        if (Polls_ddl.SelectedIndex != 0)
        {
            Polls.DeletePoll(Polls_ddl.SelectedValue.ToString());

            Messages_lb.Text = "Eliminado con éxito";
            ResetPollForm();
            GetAllPolls();
        }
    }

    protected void Answers_gv_RowCommand(object sender, GridViewCommandEventArgs e)
    {
        if (e.CommandName == "EditAnswer")
        {
            int index = Convert.ToInt32(e.CommandArgument);

            GridView answersGridView = (GridView)e.CommandSource;
            GridViewRow row = answersGridView.Rows[index];

            string answerStr = row.Cells[1].Text.Trim();

            Answer_tb.Text = HttpUtility.HtmlDecode(answerStr);
            CurrentAnswer_hf.Value = HttpUtility.HtmlDecode(answerStr);
            Answer_bt.Text = "Update Answer";
            Cancel_bt.Visible = true;
        }

        if (e.CommandName == "DeleteAnswer")
        {
            int index = Convert.ToInt32(e.CommandArgument);

            GridView answersGridView = (GridView)e.CommandSource;
            GridViewRow row = answersGridView.Rows[index];

            List<Answer> answers = (List<Answer>)Session["Answers"];

            for (int i = 0; i < answers.Count; i++)
            {
                if (answers[i].Text.Trim() == row.Cells[1].Text.Trim())
                {
                    answers.RemoveAt(i);
                }
            }

            Session["Answers"] = answers;

            Answers_gv.DataSource = Session["Answers"];
            Answers_gv.DataBind();
        }
    }
    protected void Answers_gv_RowCreated(object sender, GridViewRowEventArgs e)
    {
        if (e.Row.RowType == DataControlRowType.DataRow)
        {
            LinkButton editButton = (LinkButton)e.Row.Cells[4].Controls[0];
            editButton.CommandArgument = e.Row.RowIndex.ToString();
        }

    }
    protected void Answer_bt_Click(object sender, EventArgs e)
    {
        if (!String.IsNullOrEmpty(Answer_tb.Text))
        {
            if (Session["Answers"] != null)
            {
                List<Answer> answers = (List<Answer>)Session["Answers"];

                if (Answer_bt.Text.Trim() == "Añadir respuesta")
                {
                    Answer answer = new Answer();
                    answer.Id = Guid.NewGuid();
                    answer.Text = Answer_tb.Text;
                    answer.Vote = 0;

                    answers.Add(answer);

                    Session["Answers"] = answers;

                    Answers_gv.DataSource = Session["Answers"];
                    Answers_gv.DataBind();
                }
                else
                {
                    foreach (Answer ans in answers)
                    {
                        if (ans.Text.Trim() == CurrentAnswer_hf.Value.Trim())
                        {
                            ans.Text = Answer_tb.Text.Trim();
                        }
                    }

                    Session["Answers"] = answers;

                    Answers_gv.DataSource = Session["Answers"];
                    Answers_gv.DataBind();
                }

            }
            else
            {
                List<Answer> answers = new List<Answer>();

                Answer answer = new Answer();
                answer.Id = Guid.NewGuid();
                answer.Text = Answer_tb.Text;
                answer.Vote = 0;

                answers.Add(answer);

                Session["Answers"] = answers;

                Answers_gv.DataSource = Session["Answers"];
                Answers_gv.DataBind();
            }

            Answer_tb.Text = "";
            Answer_bt.Text = "Añadir respuesta";
            Cancel_bt.Visible = false;
        }
    }
    protected void Cancel_bt_Click(object sender, EventArgs e)
    {
        Answer_tb.Text = "";
        Answer_bt.Text = "Añadir respuesta";
        Cancel_bt.Visible = false;
    }
}