﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using BlogEngine.Core;
using BlogEngine.Core.Providers;
using System.Collections.Specialized;
using Controls;

public partial class widgets_Poll_widget : WidgetBase, ICallbackEventHandler
{
    private double totalVote;
    private string postback;

    public override string Name
    {
        get { return "Poll"; }
    }

    public override bool IsEditable
    {
        get { return true; }
    }

    public override void LoadWidget()
    {
        GetActivePoll();
    }

    private void GetActivePoll()
    {        
        Poll poll = Polls.SelectPoll();

        if (poll != null)
        {
            Question_div.InnerText = poll.Question;
            QuestionResult_div.InnerText = poll.Question;
            totalVote = poll.TotalVote;

            AnswersRbl.DataTextField = "Text";
            AnswersRbl.DataValueField = "Id";
            AnswersRbl.DataSource = poll.Answers;
            AnswersRbl.DataBind();

            Results_rpt.DataSource = poll.Answers;
            Results_rpt.DataBind();

            DateTime expirationDate = poll.ExpirationDate;
            if (expirationDate > DateTime.Parse("01/01/2008 00:00:00") && expirationDate < DateTime.Now)
            {
                PollForm.Style["display"] = "none";
                PollResult.Style["display"] = "block";
                ShowPoll.Style["display"] = "none";
                PollClosed.Style["display"] = "block";
            }

            if (IsVoted(poll.Id))
            {
                PollForm.Style["display"] = "none";
                PollResult.Style["display"] = "block";
                ShowPoll.Style["display"] = "none";
            }
        }
        else
        {
            Question_div.InnerText = "No poll";
            Vote_bt.Visible = false;
        }

        TotalVote_lb.Text = totalVote.ToString();

        StringDictionary settings = GetSettings();
        if (settings["PollsArchiveButtonVisible"] == "true")
        {
            PollsArchive.Style["display"] = "block";
        }
        else
        {
            PollsArchive.Style["display"] = "none";
        }

        if (settings["ShowResultButtonVisible"] == "true")
        {
            ShowResults.Style["display"] = "block";
        }
        else
        {
            ShowResults.Style["display"] = "none";
        }
    }

    private bool IsVoted(Guid pollId)
    {
        if (!String.IsNullOrEmpty(Request.Headers["Cookie"]))
        {
            if (Request.Cookies[pollId.ToString()] != null)
            {
                return true;
            }
            else
            {
                return false;
            }
        }
        else
        {
            return true;
        }
    }

    private void SetPoll(string answerId)
    {
        //System.Threading.Thread.Sleep(2000);

        Poll poll = Polls.SelectPoll();

        if (!IsVoted(poll.Id))
        {
            foreach (Answer answer in poll.Answers)
            {
                int vote = answer.Vote;

                if (answer.Id == new Guid(answerId))
                {
                    answer.Vote = vote + 1;
                }
            }

            if (Polls.UpdatePoll(poll, poll.Id.ToString()))
            {
                Response.Cookies[poll.Id.ToString()].Value = "voted";
                Response.Cookies[poll.Id.ToString()].Expires = DateTime.Now.AddYears(3);
            }

            postback = "true";
        }
        else
        {
            postback = "false";
        }
    }

    protected void Results_rpt_ItemDataBound(object sender, RepeaterItemEventArgs e)
    {
        if (e.Item.ItemType == ListItemType.Item || e.Item.ItemType == ListItemType.AlternatingItem)
        {
            double vote = Convert.ToDouble(((Answer)e.Item.DataItem).Vote);
            double percent = 0;

            if (vote != 0)
            {
                percent = (vote * 100) / totalVote;
            }

            ((System.Web.UI.HtmlControls.HtmlContainerControl)e.Item.FindControl("Percent_div")).InnerText = percent.ToString("F01") + "%";

            double width = (percent * 79) / 100;
            System.Globalization.CultureInfo ci = new System.Globalization.CultureInfo("en-us");
            ((System.Web.UI.HtmlControls.HtmlContainerControl)e.Item.FindControl("Progress_div")).Style["width"] = percent <= 1 ? "1px" : (width + 1).ToString("F01", ci) + "%";
        }
    }

    #region ICallbackEventHandler Members

    public string GetCallbackResult()
    {
        return postback;
    }

    public void RaiseCallbackEvent(string eventArgument)
    {
        SetPoll(eventArgument);
    }

    #endregion
}

